#Note: This script contains the analysis for all three FA types, but only the results
#looking at the SFA FA was used for the research paper


###load in required packages for categorizing the FAs into high and low groups, and ISA###

library(tidyverse)
library(phyloseq)
library(indicspecies)

###load in the pd_final_Bin_PD.RData and pd_final_Bin_Control.RData###

load("pd_final_Bin_PD.RData")
load("pd_final_Bin_Control.RData")

####Group the Data and Convert The Counts to Relative Abundance####
#Group the taxonomy ASVs in the pd_final_Bin_PD and pd_final_Bin_Control objects 
#at the Genus level, then convert the sample counts to Relative Abundance

pd_genus_PD <- tax_glom(pd_final_Bin_PD, "Genus", NArm = FALSE)
pd_genus_PD_RA <- transform_sample_counts(pd_genus_PD, fun=function(x) x/sum(x))

pd_genus_Control <- tax_glom(pd_final_Bin_Control, "Genus", NArm = FALSE)
pd_genus_Control_RA <- transform_sample_counts(pd_genus_Control, fun=function(x) x/sum(x))

###Indicator Species Analysis (ISA) of the FAs###
#ISA on Binned SFA data for both the PD and Control patients

isa_SFA_PD <- multipatt(t(otu_table(pd_genus_PD_RA)), cluster =sample_data(pd_final_Bin_PD)$`Binned_SFA`)
summary(isa_SFA_PD)

isa_SFA_Control <- multipatt(t(otu_table(pd_genus_Control_RA)), cluster =sample_data(pd_final_Bin_Control)$`Binned_SFA`)
summary(isa_SFA_Control)

#ISA on Binned MUFA data for both the PD and Control patients

isa_MUFA_PD <- multipatt(t(otu_table(pd_genus_PD_RA)), cluster =sample_data(pd_final_Bin_PD)$Binned_MUFA)
summary(isa_MUFA_PD)

isa_MUFA_Control <- multipatt(t(otu_table(pd_genus_Control_RA)), cluster =sample_data(pd_final_Bin_Control)$`Binned_MUFA`)
summary(isa_MUFA_Control)

##ISA on Binned PUFA data for both the PD and Control patients

isa_PUFA_PD <- multipatt(t(otu_table(pd_genus_PD_RA)), cluster =sample_data(pd_final_Bin_PD)$`Binned_PUFA`)
summary(isa_PUFA_PD)

isa_PUFA_Control <- multipatt(t(otu_table(pd_genus_Control_RA)), cluster =sample_data(pd_final_Bin_Control)$`Binned_PUFA`)
summary(isa_PUFA_Control)

##Extract the taxonomy table of the pd_final_Bin_PD and pd_final_Bin_Control objects##

taxtable_PD <- tax_table(pd_final_Bin_PD) %>% as.data.frame() %>% rownames_to_column(var="ASV")

taxtable_Control <- tax_table(pd_final_Bin_Control) %>% as.data.frame() %>% rownames_to_column(var="ASV")

##Merging of ISA results for each FA group with the Taxonomy data##
#Merging SFA, PUFA, and MUFA ISA results with the extracted taxonomy table 
#to create an object containing both the statistical values and the taxonomy
#names of the attained ASVs for both the PD and Control patients

isa_SFA_PD_tax<-isa_SFA_PD$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_PD) %>%
  filter(p.value<0.05)
isa_SFA_PD_tax

isa_SFA_Control_tax<-isa_SFA_Control$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_Control) %>%
  filter(p.value<0.05)
isa_SFA_Control_tax

isa_MUFA_PD_tax<-isa_MUFA_PD$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_PD) %>%
  filter(p.value<0.05)
isa_MUFA_PD_tax

isa_MUFA_Control_tax<-isa_MUFA_Control$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_Control) %>%
  filter(p.value<0.05)
isa_MUFA_Control_tax

isa_PUFA_PD_tax<-isa_PUFA_PD$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_PD) %>%
  filter(p.value<0.05)
isa_PUFA_PD_tax

isa_PUFA_Control_tax<-isa_PUFA_Control$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable_Control) %>%
  filter(p.value<0.05)
isa_PUFA_Control_tax


####Differential Expression Sequence Analysis (DESeq)####
#load in the needed package

library(tidyverse)
library(phyloseq)
library(DESeq2)
library(EnhancedVolcano)

###load in the pd_final_Bin_PD.RData and pd_final_Bin_Control.RData###

load("pd_final_Bin_PD.RData")
load("pd_final_Bin_Control.RData")

#Convert the PD and Control pd_final phyloseq objects to deseq for each binned FA
#But before doing so, transform the sample count by increasing their count
#by 1. This is because DESeq does not work well with lots of zero count

PD_Plus1 <- transform_sample_counts(pd_final_Bin_PD, function(x) x+1)
Control_Plus1 <- transform_sample_counts(pd_final_Bin_Control, function(x) x+1)

PD_SFA_deseq <- phyloseq_to_deseq2(PD_Plus1, ~Binned_SFA)
DESeq_PD_SFA <- DESeq(PD_SFA_deseq)

PD_MUFA_deseq <- phyloseq_to_deseq2(PD_Plus1, ~Binned_MUFA)
DESeq_PD_MUFA <- DESeq(PD_MUFA_deseq)

PD_PUFA_deseq <- phyloseq_to_deseq2(PD_Plus1, ~Binned_PUFA)
DESeq_PD_PUFA <- DESeq(PD_PUFA_deseq)

Control_SFA_deseq <- phyloseq_to_deseq2(Control_Plus1, ~Binned_SFA)
DESeq_Control_SFA <- DESeq(Control_SFA_deseq)

Control_MUFA_deseq <- phyloseq_to_deseq2(Control_Plus1, ~Binned_MUFA)
DESeq_Control_MUFA <- DESeq(Control_MUFA_deseq)

Control_PUFA_deseq <- phyloseq_to_deseq2(Control_Plus1, ~Binned_PUFA)
DESeq_Control_PUFA <- DESeq(Control_PUFA_deseq)

#Create an object for each FA and Disease condition that contains the DESeq results
#for each sample, set the Low binned fat as the reference group and the High fat
#group as the comparison group

PD_SFA_Res <- results(DESeq_PD_SFA, tidy = TRUE, 
                      contrast = c("Binned_SFA", "Low", "High")) 

PD_MUFA_Res <- results(DESeq_PD_MUFA, tidy = TRUE, 
                      contrast = c("Binned_MUFA", "Low", "High"))

PD_PUFA_Res <- results(DESeq_PD_PUFA, tidy = TRUE, 
                      contrast = c("Binned_PUFA", "Low", "High")) 

Control_SFA_Res <- results(DESeq_Control_SFA, tidy = TRUE, 
                      contrast = c("Binned_SFA", "Low", "High")) 

Control_MUFA_Res <- results(DESeq_Control_MUFA, tidy = TRUE, 
                           contrast = c("Binned_MUFA", "Low", "High")) 

Control_PUFA_Res <- results(DESeq_Control_PUFA, tidy = TRUE, 
                           contrast = c("Binned_PUFA", "Low", "High")) 

###Creating Enhanced Volcano Plots###
#Create enhanced volcano plots of each result to get a grasp of how each distribution
#looks like.

vol_plot_PD_SFA <- PD_SFA_Res %>%
  EnhancedVolcano(lab = rownames(PD_SFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value', 'p-value', 'p-value & Log_2FoldChange'))
vol_plot_PD_SFA

vol_plot_PD_MUFA <- PD_MUFA_Res %>%
  EnhancedVolcano(lab = rownames(PD_MUFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value', 'p-value', 'p-value & Log_2FoldChange'))
vol_plot_PD_MUFA 

vol_plot_PD_PUFA <- PD_PUFA_Res %>%
  EnhancedVolcano(lab = rownames(PD_PUFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value','p-value', 'p-value & Log_2FoldChange'))
vol_plot_PD_PUFA

vol_plot_Control_SFA <- Control_SFA_Res %>%
  EnhancedVolcano(lab = rownames(Control_SFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value', 'p-value', 'p-value & Log_2FoldChange'))
vol_plot_Control_SFA

vol_plot_Control_MUFA <- Control_MUFA_Res %>%
  EnhancedVolcano(lab = rownames(Control_MUFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value', 'p-value', 'p-value & Log_2FoldChange'))
vol_plot_Control_MUFA

vol_plot_Control_PUFA <- Control_PUFA_Res %>%
  EnhancedVolcano(lab = rownames(Control_PUFA_Res), x = 'log2FoldChange', y = 'pvalue',
  pCutoff = 0.05, FCcutoff = 2, col = c('black', 'blue', 'red1'),
  colAlpha = 0.5, legendLabels = c('NS', 'p-value', 'p-value', 'p-value & Log_2FoldChange'))
vol_plot_Control_PUFA

###Convert the Results to Represent only Significant ASVs###
#convert the results objects for both PD and Control patients to represent only
#the significant ASVs which were seen in the volcano plot above. Set the same 
#padj and abs(log2folchange) threshold as in the Volcano plots

PD_SFA_sigASVs <- PD_SFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

PD_MUFA_sigASVs <- PD_MUFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

PD_PUFA_sigASVs <- PD_PUFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

Control_SFA_sigASVs <- Control_SFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

Control_MUFA_sigASVs <- Control_MUFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

Control_PUFA_sigASVs <- Control_PUFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

#Save the significant ASV names for each condition for pruning the phyloseq file
#to create a bar plot

PD_SFA_sigASVs_Vec <- PD_SFA_sigASVs %>% pull(ASV)
PD_MUFA_sigASVs_Vec <- PD_MUFA_sigASVs %>% pull(ASV)
PD_PUFA_sigASVs_Vec <- PD_PUFA_sigASVs %>% pull(ASV)

Control_SFA_sigASVs_Vec <- Control_SFA_sigASVs %>% pull(ASV)
Control_MUFA_sigASVs_Vec <- Control_MUFA_sigASVs %>% pull(ASV)
Control_PUFA_sigASVs_Vec <- Control_PUFA_sigASVs %>% pull(ASV)

###Pruning the phyloseq files for each FA###
#Repeat the pruning process per each FA fo both the PD and Control condition and
#join this prune result with the significant ASVs object of each FA and their 
#respective culture

PD_SFA_sigASVs <- tax_table(prune_taxa(PD_SFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(PD_SFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

PD_MUFA_sigASVs <- tax_table(prune_taxa(PD_MUFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(PD_MUFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

PD_PUFA_sigASVs <- tax_table(prune_taxa(PD_PUFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(PD_PUFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

Control_SFA_sigASVs <- tax_table(prune_taxa(Control_SFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(Control_SFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

Control_MUFA_sigASVs <- tax_table(prune_taxa(Control_MUFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(Control_MUFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

Control_PUFA_sigASVs <- tax_table(prune_taxa(Control_PUFA_sigASVs_Vec,pd_final_Bin_PD)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(Control_PUFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

#Remove the unnecessary strings of letter followed by two underlines for the genus column
PD_SFA_sigASVs$Genus <- substring(PD_SFA_sigASVs$Genus, 4)

####Create a Bar plot of the final results and save them####
#for each FA in either PD or Control conditions, create a bar plot that 
#illustrates which genus have increased or decreased relative to low binned FA 
#reference group, and save a picture of these bar plots

PD_SFA_Barplot <- ggplot(PD_SFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

PD_MUFA_Barplot <- ggplot(PD_MUFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

PD_PUFA_Barplot <- ggplot(PD_PUFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

Control_SFA_Barplot <- ggplot(Control_SFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

Control_MUFA_Barplot <- ggplot(Control_MUFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

Control_PUFA_Barplot <- ggplot(Control_PUFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

###(for presentation, only show PD MUFA and SFA plots)####

ggsave(PD_SFA_Barplot, file="PD_SFA_Barplot.PNG", width = 6, height = 8)
ggsave(PD_MUFA_Barplot, file="PD_MUFA_Barplot.PNG", width = 6, height = 8)
ggsave(PD_PUFA_Barplot, file="PD_PUFA_Barplot.PNG", width = 6, height = 8)
ggsave(Control_SFA_Barplot, file="Control_SFA_Barplot.PNG", width = 6, height = 8)
ggsave(Control_MUFA_Barplot, file="Control_MUFA_Barplot.PNG", width = 6, height = 8)
ggsave(Control_PUFA_Barplot, file="Control_PUFA_Barplot.PNG", width = 6, height = 8)

####DESeq analysis between Low SFA of PD vs Control patients####
#Change the Low values in the Control_Plus1 phyloseq object to Low_Control
#in order to merge the Control_Plus1 with PD_Plus1 for running the DESeq functions.
#This is done to set the Low SFA values in the Binned_SFA column of control as the reference group

load("pd_final.RData")
pd_final_plus1 <- transform_sample_counts(pd_final, function(x) x+1)

sample_data(Control_Plus1)$Binned_SFA <- as.character(sample_data(Control_Plus1)$Binned_SFA)
sample_data(Control_Plus1)$Binned_SFA[as.data.frame(sample_data(Control_Plus1))$Binned_SFA == 'Low'] <- 'Low_Control'
sample_data(pd_final_plus1) <- rbind(sample_data(Control_Plus1), sample_data(PD_Plus1))

#Normal DESeq codes to create a final Bar plot that shows the log2Fold change of
#the PD Low SFA species relative to Control Low SFA

merged_SFA_deseq <- phyloseq_to_deseq2(pd_final_plus1, ~Binned_SFA)
DESeq_merged_SFA <- DESeq(merged_SFA_deseq)

merged_SFA_Res <- results(DESeq_merged_SFA, tidy = TRUE, 
                          contrast = c("Binned_SFA", "Low", "Low_Control")) 

merged_SFA_sigASVs <- merged_SFA_Res %>% 
  filter(pvalue<0.05 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

merged_SFA_sigASVs_Vec <- merged_SFA_sigASVs %>% pull(ASV)

merged_SFA_sigASVs <- tax_table(prune_taxa(merged_SFA_sigASVs_Vec,pd_final)) %>% 
  as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(merged_SFA_sigASVs) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

merged_SFA_sigASVs$Genus <- substring(merged_SFA_sigASVs$Genus, 4)

merged_SFA_Barplot <- ggplot(merged_SFA_sigASVs) +
  geom_bar(aes(x=Genus, y=log2FoldChange, fill = log2FoldChange < 0), stat="identity")+
  geom_errorbar(aes(x=Genus, ymin=log2FoldChange-lfcSE, ymax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(angle=90, hjust=1, vjust=0.5), legend.position = "none") +
  scale_fill_manual(values = c('green', 'red'))

ggsave(merged_SFA_Barplot, file="PD_vs_Control_Low_SFA_Barplot.PNG", width = 6, height = 8)

####Core-microbiome Analysis####
#load in the needed packages

library(tidyverse)
library(phyloseq)
library(microbiome)
library(ggVennDiagram)

##load in the needed files##

load("pd_final_Bin_PD.RData")
load("pd_final_Bin_Control.RData")

#Convert the phyloseq object so that they show relative abundance

pd_final_Bin_PD_RA <- transform_sample_counts(pd_final_Bin_PD, fun=function(x) x/sum(x))
pd_final_Bin_Control_RA <- transform_sample_counts(pd_final_Bin_Control, fun=function(x) x/sum(x))

#filter the Data for both Control and PD objects to only show High and low

SFA_Bin_PD_High <- subset_samples(pd_final_Bin_PD_RA, Binned_SFA=="High")
SFA_Bin_PD_Low <- subset_samples(pd_final_Bin_PD_RA, Binned_SFA=="Low")

MUFA_Bin_PD_High <- subset_samples(pd_final_Bin_PD_RA,Binned_MUFA=="High")
MUFA_Bin_PD_Low <- subset_samples(pd_final_Bin_PD_RA, Binned_MUFA=="Low")

PUFA_Bin_PD_High <- subset_samples(pd_final_Bin_PD_RA, Binned_PUFA=="High")
PUFA_Bin_PD_Low <- subset_samples(pd_final_Bin_PD_RA, Binned_PUFA=="Low")

SFA_Bin_Control_High <- subset_samples(pd_final_Bin_Control_RA, Binned_SFA=="High")
SFA_Bin_Control_Low <- subset_samples(pd_final_Bin_Control_RA, Binned_SFA=="Low")

MUFA_Bin_Control_High <- subset_samples(pd_final_Bin_Control_RA, Binned_MUFA=="High")
MUFA_Bin_Control_Low <- subset_samples(pd_final_Bin_Control_RA, Binned_MUFA=="Low")

PUFA_Bin_Control_High <- subset_samples(pd_final_Bin_Control_RA, Binned_PUFA=="High")
PUFA_Bin_Control_Low <- subset_samples(pd_final_Bin_Control_RA, Binned_PUFA=="Low")

#Filter out the ASVs so that only the ones that are either present or absent in
#in 80% of the samples only remain for each FA in both Control and PD conditions

PD_SFA_High_ASVs <- core_members(SFA_Bin_PD_High, detection=0, prevalence = 0.8)
PD_SFA_Low_ASVs <- core_members(SFA_Bin_PD_Low, detection = 0, prevalence = 0.8)

PD_MUFA_High_ASVs <- core_members(MUFA_Bin_PD_High, detection=0, prevalence = 0.8)
PD_MUFA_Low_ASVs <- core_members(MUFA_Bin_PD_Low, detection = 0, prevalence = 0.8)

PD_PUFA_High_ASVs <- core_members(PUFA_Bin_PD_High, detection=0, prevalence = 0.8)
PD_PUFA_Low_ASVs <- core_members(PUFA_Bin_PD_Low, detection = 0, prevalence = 0.8)

Control_SFA_High_ASVs <- core_members(SFA_Bin_Control_High, detection=0, prevalence = 0.8)
Control_SFA_Low_ASVs <- core_members(SFA_Bin_Control_Low, detection = 0, prevalence = 0.8)

Control_MUFA_High_ASVs <- core_members(MUFA_Bin_Control_High, detection=0, prevalence = 0.8)
Control_MUFA_Low_ASVs <- core_members(MUFA_Bin_Control_Low, detection = 0, prevalence = 0.8)

Control_PUFA_High_ASVs <- core_members(PUFA_Bin_Control_High, detection=0, prevalence = 0.8)
Control_PUFA_Low_ASVs <- core_members(PUFA_Bin_Control_Low, detection = 0, prevalence = 0.8)

#Create a taxonomy table that shows the ASV results attained above for the 
#core_members() code

data.frame(tax_table(prune_taxa(PD_SFA_High_ASVs, pd_final_Bin_PD)))
data.frame(tax_table(prune_taxa(PD_SFA_Low_ASVs, pd_final_Bin_PD)))

tax_table(prune_taxa(PD_MUFA_High_ASVs, pd_final_Bin_PD))
tax_table(prune_taxa(PD_MUFA_Low_ASVs, pd_final_Bin_PD))

tax_table(prune_taxa(PD_PUFA_High_ASVs, pd_final_Bin_PD))
tax_table(prune_taxa(PD_PUFA_Low_ASVs, pd_final_Bin_PD))

data.frame(tax_table(prune_taxa(Control_SFA_High_ASVs, pd_final_Bin_Control)))
data.frame(tax_table(prune_taxa(Control_SFA_Low_ASVs, pd_final_Bin_Control)))

tax_table(prune_taxa(Control_MUFA_High_ASVs, pd_final_Bin_Control))
tax_table(prune_taxa(Control_MUFA_Low_ASVs, pd_final_Bin_Control))

tax_table(prune_taxa(Control_PUFA_High_ASVs, pd_final_Bin_Control))
tax_table(prune_taxa(Control_PUFA_Low_ASVs, pd_final_Bin_Control))

#Now, illustrate these ASV results as a bar plot at the Genus level for just
#visualization

prune_taxa(PD_SFA_High_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(PD_SFA_Low_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

prune_taxa(PD_MUFA_High_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(PD_MUFA_Low_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

prune_taxa(PD_PUFA_High_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(PD_PUFA_Low_ASVs,pd_final_Bin_PD_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

prune_taxa(Control_SFA_High_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(Control_SFA_Low_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

prune_taxa(Control_MUFA_High_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(Control_MUFA_Low_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

prune_taxa(Control_PUFA_High_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")
prune_taxa(Control_PUFA_Low_ASVs,pd_final_Bin_Control_RA) %>% 
  plot_bar(fill="Genus") + 
  facet_wrap(.~`Binned_SFA`, scales ="free")

#Create two types of lists for each FA, one containing only High FA results
#between PD and Control patients, and another containing only Low FA results
#between PD and Control patients. This will be used to create a Venn Diagram

High_SFA_List <- list(PD = PD_SFA_High_ASVs, Control = Control_SFA_High_ASVs)
High_MUFA_List <- list(PD = PD_MUFA_High_ASVs, Control = Control_MUFA_High_ASVs)
High_PUFA_List <- list(PD = PD_PUFA_High_ASVs, Control = Control_PUFA_High_ASVs)

Low_SFA_List <- list(PD = PD_SFA_Low_ASVs, Control = Control_SFA_Low_ASVs)
Low_MUFA_List <- list(PD = PD_MUFA_Low_ASVs, Control = Control_MUFA_Low_ASVs)
Low_PUFA_List <- list(PD = PD_PUFA_Low_ASVs, Control = Control_PUFA_Low_ASVs)

#Create a Venn Diagram for each list above and save it

High_SFA_Venn <- ggVennDiagram(x = High_SFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "High_SFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))
High_MUFA_Venn <- ggVennDiagram(x = High_MUFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "High_MUFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))
High_PUFA_Venn <- ggVennDiagram(x = High_PUFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "High_PUFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))

Low_SFA_Venn <- ggVennDiagram(x = Low_SFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "Low_SFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))
Low_MUFA_Venn <- ggVennDiagram(x = Low_MUFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "Low_MUFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))
Low_PUFA_Venn <- ggVennDiagram(x = Low_PUFA_List, set_color = "red", label = "count", label_size = 7, set_size = 7) +
  labs(title = "Low_PUFA") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))

ggsave("High_SFA_VennDiagram.png", High_SFA_Venn)
ggsave("High_MUFA_VennDiagram.png", High_MUFA_Venn)
ggsave("High_PUFA_VennDiagram.png", High_PUFA_Venn)
ggsave("Low_SFA_VennDiagram.png", Low_SFA_Venn)
ggsave("Low_MUFA_VennDiagram.png", Low_MUFA_Venn)
ggsave("Low_PUFA_VennDiagram.png", Low_PUFA_Venn)

###Making a Venn Diagram that looks at PD vs Control for both High and Low SFA Values###
Venn <- list(PD_High = PD_SFA_High_ASVs, PD_Low = PD_SFA_Low_ASVs, Control_Low = Control_SFA_Low_ASVs, Control_High = Control_SFA_High_ASVs)

SFA_PD_vs_Control <- ggVennDiagram(x = Venn, set_color = "red", label = "count", label_size = 7, set_size = 4) +
  labs(title = "SFA PD vs. Control") +
  theme(legend.position = "none", title = element_text(colour = "red", size = 15))+
  scale_fill_gradient(low = "White", high = "blue") +
  scale_x_continuous(expand = expansion(mult = .2))
ggsave("SFA_PD_vs_Control_VennDiagram.png", SFA_PD_vs_Control)

